Realizar uma avaliação de riscos com OiRA | OiRA

Temas

# Realizar uma avaliação de riscos com OiRA

## Iniciar uma nova sessão

Para iniciar uma nova avaliação de riscos, clique na ligação «Iniciar uma nova sessão».

## Abrir uma avaliação de riscos

Uma vez iniciada uma avaliação de riscos, pode voltar a aceder à mesma em qualquer momento através da opção «As minhas avaliações de riscos» no painel de comandos. A partir desta opção, pode também iniciar uma nova avaliação de riscos.

O painel de comandos.

## Explorar uma avaliação de riscos

Em cada avaliação de riscos, será orientado para várias etapas. Essas etapas estão visíveis no menu principal situado no lado esquerdo do ecrã:

- Preparação
- Participação
- Identificação + Avaliação
- Plano de ação
- Relatório
- Estado

A estrutura de cada ferramenta pode variar em função das decisões tomadas pelos parceiros OiRA/programadores da ferramenta OiRA. Em algumas ferramentas, a fase de identificação e avaliação dos riscos inclui o plano de ação. Nesse caso, o menu à esquerda apresenta a seguinte estrutura:

- Preparação
- Participação
- Avaliação
- Relatório
- Estado

## Preparação

A etapa «Preparação» corresponde ao momento em que inicia cada sessão/ferramenta. É nesta fase que deve atribuir à avaliação de riscos um nome que mais tarde o ajudará a distinguir entre várias avaliações de riscos que tenha efetuado com esta ferramenta.

A ligação «Saiba mais sobre esta ferramenta…» fornece mais informações sobre a ferramenta selecionada e sobre as partes que estiveram envolvidas no seu desenvolvimento.

Após clicar em «Iniciar», poderão ser-lhe colocadas algumas perguntas adicionais, dependendo da ferramenta que estiver a utilizar. Este ecrã preparatório com «perguntas relacionadas com o perfil» aparece apenas com ferramentas que oferecem esta opção.

Nesta etapa, pode:

- Selecionar ou ignorar situações, conforme estas se aplicarem à sua atividade profissional. Escolher «sim», quando apropriado.
- Listar várias unidades, sucursais, lojas, etc., da empresa. Os riscos correspondentes serão repetidos para cada entrada.

O ecrã “Perfil” na etapa de preparação

A etapa de preparação é muito importante, pois define de forma precisa o tipo de atividade profissional e os riscos conexos a que a sua empresa poderá estar exposta. Depois de clicar em «Guardar e continuar», será reencaminhado para a próxima etapa, «Participação».

Nota: Muitas ferramentas não incluem perguntas de perfil, na medida em que não utilizam esta funcionalidade para direcionar a ferramenta. Nesse caso, este ecrã é ignorado automaticamente.

## Participação

Esta etapa serve para lembrar a importância da participação dos trabalhadores no processo e apresenta diferentes formas de assegurar uma boa participação dos trabalhadores. Nesta etapa, pode descarregar ou imprimir o conteúdo das avaliações de riscos para as partilhar com os seus trabalhadores/funcionários. Essa possibilidade assegura que os trabalhadores possam contribuir para avaliar a situação no seu local de trabalho.

## Avaliação

Nesta etapa, poderá identificar os perigos e problemas relevantes que existem na sua empresa.

Nota: Dependendo da forma como a ferramenta foi configurada pelo parceiro OiRA, a etapa do «Plano de ação» (ver abaixo) pode ser integrada neste ecrã. Neste caso, toda a etapa é denominada «Avaliação» e os elementos descritos no «Plano de Ação» serão apresentados na identificação e avaliação de cada risco.

Identificação e Avaliação

No lado esquerdo do ecrã, por baixo de «Identificação + Avaliação»/«Avaliação», pode ver cada um dos tópicos/módulos incluídos na ferramenta. O tópico que estiver a visualizar no momento surgirá realçado.

### Identificação

Para cada risco, deve determinar se a afirmação que descreve uma situação desejada se aplica à sua empresa. Pode responder da seguinte forma:

- Sim: se responder «sim» à afirmação, não são necessárias mais ações, uma vez que avaliou o risco como inexistente.
- Não: se responder «não» à afirmação, será necessário adotar novas medidas. Ser-lhe-á solicitado que defina medidas específicas.
- Não aplicável: para algumas afirmações sobre riscos, existe a possibilidade de selecionar a opção «não aplicável» se o risco não for relevante para a sua empresa/estabelecimento.

Por baixo de cada afirmação, são normalmente apresentadas mais informações sobre o risco específico:

- Informação: uma breve descrição, por vezes acompanhada de imagens, fornecendo mais detalhes sobre o risco.
- Recursos: informações adicionais sobre o risco, tais como referências sobre legislação e sobre políticas. Por vezes, é possível encontrar, neste campo, documentos sob a forma de anexo para posterior leitura.
- Observações: pode aqui apresentar as suas observações, que serão incluídas no seu relatório no final da avaliação.

Depois de fornecer a sua resposta a uma afirmação sobre riscos e prosseguir, o menu à esquerda será atualizado com um símbolo colorido para indicar se:

- respondeu de forma positiva (sinal de visto verde)
- respondeu de forma negativa (cruz vermelha)
- adiou a resposta (ponto de interrogação laranja)

Nas perguntas não respondidas, mantém-se o símbolo cinza.

### Avaliação

Nesta etapa, deve avaliar a prioridade de um risco por si identificado.

Avaliar um risco.

Nota: Em algumas ferramentas OiRA, a avaliação não é apresentada. Isso depende da forma como o parceiro nacional OiRA/programador da ferramenta OiRA elaborou a sua ferramenta específica.

Se tiver identificado um risco como estando presente (assinalado com uma cruz vermelha), surgirá uma secção para avaliar esse risco. Dependendo do método de avaliação definido para cada risco, será solicitado que:

- determine a prioridade: alta, média ou baixa

Definir a prioridade de um risco.

OU

- responda a algumas perguntas sobre a frequência, a gravidade e a probabilidade do risco, para que a prioridade possa ser calculada com base nas suas respostas.

Definir variáveis para um risco.

### Riscos prioritários definidos pelo setor:

Alguns riscos são considerados muito importantes pelo parceiro nacional OiRA/programador da ferramenta OiRA específica. Não é obrigado a determinar esses «riscos prioritários», uma vez que a prioridade dos riscos em causa será automaticamente definida como «elevada».

Riscos prioritários.

### Riscos personalizados

Depois de responder a todos os tópicos relativos aos riscos na secção «Identificação + Avaliação»/«Avaliação», chegará ao tópico opcional «Outros riscos». Neste campo, o botão «Adicionar um risco personalizado» permite criar as suas próprias entradas.

Se houver riscos que não estão previstos na ferramenta, mas que estão presentes no seu local de trabalho/na sua empresa, deverá adicioná-los neste campo. Estes riscos podem ser totalmente definidos/formulados por si.

Riscos personalizados.

O procedimento para indicar um «risco personalizado» é muito semelhante ao procedimento para os riscos pré-definidos pela ferramenta OiRA, mas será, obviamente, necessário descrever esse risco por palavras suas. O texto a inserir deve, no mínimo, corresponder a uma breve descrição de uma situação problemática, podendo, no entanto, ser feita uma descrição mais alargada. É também possível carregar uma imagem para ilustrar uma determinada situação.

Tal como acontece com os riscos normais, é necessário indicar se o risco está ou não presente. Isso permitirá retirar a sinalização dos riscos personalizados depois de estes serem resolvidos, sem deixar que estes riscos fiquem incluídos na sua avaliação de riscos, para fins de documentação.

Pode adicionar todos os riscos personalizados que necessitar.

Adicionar um risco personalizado

## Plano de ação

Nesta etapa, deve determinar as medidas que pretende implementar para eliminar ou mitigar os riscos por si identificados.

Nota: Tal como acima referido, o plano de ação é apresentado como uma etapa separada no menu à esquerda ou aparece para cada risco identificado. Neste último caso, a etapa do menu passa a ter o nome de «Avaliação» e inclui tanto as perguntas com afirmações sobre riscos como as respostas de escolha múltipla.

A versão que lhe é fornecida depende das decisões tomadas pelo parceiro nacional OiRA/programador da ferramenta OiRA.

### Plano de ação integrado

Plano de ação integrado

Se responder «não» a uma pergunta, o módulo de plano de ação será apresentado na página, sob o título «Medidas».

Pode selecionar medidas a partir de uma lista proposta pelo sistema ou definir as suas próprias medidas.

### Plano de ação separado

Quando o plano de ação for apresentado como uma etapa separada, poderá aceder ao mesmo através do menu de navegação à esquerda.

Clique no botão «Criar plano de ação» para iniciar o seu plano.

Na etapa de plano de ação, o menu à esquerda passa a apresentar apenas os riscos assinalados que exigirão novas ações, uma vez que os outros riscos foram assinalados como inexistentes.

Para cada risco em que tenha sido respondido «não» durante o processo de avaliação e para os riscos prioritários (independentemente de a resposta ter sido «sim» ou «não»), ser-lhe-á solicitado que defina medidas.

Um risco no plano de ação.

Pode selecionar medidas a partir da lista sugerida pelo sistema ou definir as suas próprias medidas.

#### Adicionar a sua própria medida

Adicionar uma medida adicional.

Utilize o botão «Adicionar uma medida» para começar a definir uma medida preventiva. Deverá:

- Descrever a abordagem geral a adotar para eliminar ou reduzir o risco.
- Opcionalmente, indicar o nível de especialização e/ou os requisitos necessários (pode, por exemplo, indicar a eventual necessidade de formação específica ou de recurso a um especialista externo para lidar com esse risco)
- Indicar informações sobre quem é responsável pela implementação da medida.
- Definir um orçamento, se aplicável.
- Opcionalmente, definir datas para o início da implementação da medida e uma data em que tenciona concluí-la.

Pode adicionar todas as medidas que considerar necessárias.

#### Adicionar medidas padrão

Dependendo da forma como o parceiro nacional OiRA/programador desenvolveu a ferramenta OiRA, estão disponíveis medidas predefinidas para riscos individuais. Para escolher uma ou mais medidas predefinidas, clique no botão «Selecionar medidas padrão».

Será aberto um menu instantâneo que apresentará todas as medidas sugeridas. Clique no botão «Adicionar» para introduzir aquelas que deseja aplicar.

As medidas predefinidas selecionadas passarão em seguida a constar do seu plano de ação. A descrição dos procedimentos concretos não pode ser alterada, mas os outros campos (responsabilidade, orçamento, datas) podem e devem ser preenchidos por si.

Adicionar medidas padrão.

Tanto as medidas padrão como as medidas definidas por si podem ser novamente excluídas em qualquer momento.

## Relatório

Depois de finalizar o plano de ação, pode produzir um relatório.

Se quiser incluir um comentário no relatório, digite o seu texto neste campo e guarde-o.

Comentário para o relatório.

Aceda aqui para saber mais sobre os diferentes tipos de relatório e sobre como usá-los.

## Estado

O pequeno gráfico circular no menu à esquerda mostra o estado de progressão relativo à sua utilização da ferramenta.

A secção relativa ao estado de progressão fornece uma visão geral do número de riscos identificados por si, do número de riscos em relação aos quais foram definidas medidas e do número de riscos/perguntas para os quais não ainda forneceu respostas.

A página de estado.

Quando estiver no ecrã de estado, pode ver o seu estado de progressão em cada módulo. Isso permite-lhe verificar mais facilmente quais são os riscos que ainda não foram avaliados por si ou fornecer medidas em falta para os riscos que identificou.

Scroll to top Load toolbar…
Back

## 3-carrying-out-a-risk-assessment.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More